@@ -1,7 +1,7 @@
 #!/usr/bin/env bash
 set -e
 
-PYTHON_VERSIONS="${PYTHON_VERSIONS-3.6 3.7 3.8 3.9 3.10 3.11}"
+PYTHON_VERSIONS="${PYTHON_VERSIONS-3.7 3.8 3.9 3.10 3.11}"
 
 install_with_pipx() {
     if ! command -v "$1" &>/dev/null; then
@@ -14,7 +14,17 @@ install_with_pipx() {
 
 install_with_pipx pdm
 
+restore_previous_python_version() {
+    if pdm use -f "$1" &>/dev/null; then
+        echo "> Restored previous Python version: ${1##*/}"
+    fi
+}
+
 if [ -n "${PYTHON_VERSIONS}" ]; then
+    if old_python_version="$(pdm config python.path 2>/dev/null)"; then
+        echo "> Currently selected Python version: ${old_python_version##*/}"
+        trap "restore_previous_python_version ${old_python_version}" EXIT
+    fi
     for python_version in ${PYTHON_VERSIONS}; do
         if pdm use -f "python${python_version}" &>/dev/null; then
             echo "> Using Python ${python_version} interpreter"
